@@ -16,6 +16,7 @@ def fun_control_init(
     SUMMARY_WRITER=True,
     accelerator="auto",
     converters=None,
+    core_model=None,
     data=None,
     data_dir="./data",
     data_module=None,
@@ -35,10 +36,12 @@ def fun_control_init(
     metric_sklearn=None,
     noise=False,
     n_points=1,
+    n_samples=None,
     num_workers=0,
     ocba_delta=0,
     oml_grace_period=None,
     optimizer=None,
+    prep_model=None,
     seed=123,
     show_models=False,
     show_progress=True,
@@ -69,6 +72,10 @@ def fun_control_init(
             The accelerator to be used by the Lighting Trainer.
             It can be either "auto", "dp", "ddp", "ddp2", "ddp_spawn", "ddp_cpu", "gpu", "tpu".
             Default is "auto".
+        converters (dict):
+            A dictionary containing the converters. Default is None.
+        core_model (object):
+            The core model object. Default is None.
         data (object):
             The data object. Default is None.
         data_dir (str):
@@ -120,6 +127,8 @@ def fun_control_init(
             Affects the repeat of the function evaluations.
         n_points (int):
             The number of infill points to be generated by the surrogate in each iteration.
+        n_samples (int):
+            The number of samples in the dataset. Default is None.
         num_workers (int):
             The number of workers to use for the data loading. Default is 0.
         ocba_delta (int):
@@ -132,6 +141,8 @@ def fun_control_init(
         PREFIX (str):
             The prefix of the experiment name. If the PREFIX is not None, a spotWriter
             that us an instance of a SummaryWriter(), is created. Default is None.
+        prep_model (object):
+            The preprocessing model object. Used for river. Default is None.
         seed (int):
             The seed to use for the random number generator. Default is 123.
         sigma (float):
@@ -281,6 +292,8 @@ def fun_control_init(
         "_L_in": _L_in,
         "_L_out": _L_out,
         "accelerator": accelerator,
+        "converters": converters,
+        "core_model": core_model,
         "counter": 0,
         "data": data,
         "data_dir": data_dir,
@@ -308,13 +321,13 @@ def fun_control_init(
         "model_dict": {},
         "noise": noise,
         "n_points": n_points,
-        "n_samples": None,
+        "n_samples": n_samples,
         "num_workers": num_workers,
         "ocba_delta": ocba_delta,
         "oml_grace_period": oml_grace_period,
         "optimizer": optimizer,
         "path": None,
-        "prep_model": None,
+        "prep_model": prep_model,
         "save_model": False,
         "seed": seed,
         "show_batch_interval": 1_000_000,
